==> bayonne-0.6.3.tar.gz: bayonne-0.6.3/drivers/vpb/dial.cpp <==
// Copyright (C) 2000 Open Source Telecom Corporation.
//  
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software 
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
#include "driver.h"

#include <pthread.h>

void *startDialThread(void *pv);

bool VPBTrunk::dialHandler(TrunkEvent *event)
{
	pthread_t DialThread;

	
	switch(event->id)
	{
	case TRUNK_ENTER_STATE:
	  slog(SLOG_INFO) <<__FILE__<<" line "<<__LINE__<< " received  TRUNK_ENTER_STATE"<<endl;	
		debug->DebugState(this, "flashoff");
		flags.offhook = true;
		vpb_sethook_async(handle, VPB_OFFHOOK);
		if(data.dialxfer.offhook < getPickupTimer())
			data.dialxfer.offhook = getPickupTimer();
		setTimer(data.dialxfer.offhook);
		slog(SLOG_INFO) <<__FILE__<<" line "<<__LINE__<< " start dial thread..."<<endl;
		pthread_create(&DialThread, NULL, startDialThread,(void*)this);

		return true;
        case TRUNK_LINE_WINK:
		slog(SLOG_INFO) <<__FILE__<<" line " <<__LINE__<< " received TRUNK_LINE_WINK" <<endl;
		TrunkSignal(TRUNK_SIGNAL_STEP);
		handler = &VPBTrunk::stepHandler;

                return true;
	}

	slog(SLOG_INFO) <<__FILE__<<" line "<<__LINE__<< " received not  TRUNK_ENTER_STATE and not TRUNK_LINE_WINK, it is="<< event->id <<endl;
	return false;
}

// thread spawned by event handler to handle sync dialing (sorry about
// hacking this David S, I should really learn how to use your thread
// class :-) ).  Please feel free to clean up! DR 4/6/01

// pthread can only start C functions, this function then immediately starts
// a trunk member function to handle the actual dialling
void *startDialThread(void *pv) {
  VPBTrunk *trunk = (VPBTrunk*)pv;
  
  trunk->DialSync();
}

// This functions waits for sync (blocking) dial function to finish, then
// posts a finish event.  We need this in a separate thread to prevent 
// sync dial function from blocking other vpb events. 

void VPBTrunk::DialSync() {
  TrunkEvent event;

  slog(SLOG_INFO) <<__FILE__<<" line "<<__LINE__<< " digits= "<<data.dialxfer.digits << endl;

  slog(SLOG_INFO) <<__FILE__<<" line "<<__LINE__<< " dialing ..."<<endl;

  vpb_dial_sync(handle, data.dialxfer.digits);

  slog(SLOG_INFO) <<__FILE__<<" line "<<__LINE__<< " dialed ..."<<endl;

  event.id =  TRUNK_LINE_WINK;

  postEvent(&event);
}

==> bayonne-0.6.5.tar.gz: bayonne-0.6.5/drivers/vpb/dial.cpp <==
// Copyright (C) 2000 Open Source Telecom Corporation.
//  
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software 
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
#include "driver.h"

#include <pthread.h>

void *startDialThread(void *pv);

bool VPBTrunk::dialHandler(TrunkEvent *event)
{
	
	switch(event->id)
	{
	case TRUNK_ENTER_STATE:
		slog(SLOG_INFO) <<__FILE__<<" line "<<__LINE__<< 
			" received  TRUNK_ENTER_STATE"<<endl;	
		debug->DebugState(this, "flashoff");
		flags.offhook = true;
		vpb_sethook_async(handle, VPB_OFFHOOK);
		if(data.dialxfer.offhook < getPickupTimer())
			data.dialxfer.offhook = getPickupTimer();
		setTimer(data.dialxfer.offhook);
		slog(SLOG_INFO) <<__FILE__<<" line "<<__LINE__<< 
			" start dial thread..."<<endl;
		pthread_create(&DialThread, NULL, startDialThread,(void*)this);

		return true;
        case TRUNK_LINE_WINK:
		slog(SLOG_INFO) <<__FILE__<<" line " <<__LINE__<< 
			" received TRUNK_LINE_WINK" <<endl;
		TrunkSignal(TRUNK_SIGNAL_STEP);
		handler = &VPBTrunk::stepHandler;

                return true;
	}

	return false;
}

// thread spawned by event handler to handle sync dialing (sorry about
// hacking this David S, I should really learn how to use your thread
// class :-) ).  Please feel free to clean up! DR 4/6/01

// pthread can only start C functions, this function then immediately starts
// a trunk member function to handle the actual dialling
void *startDialThread(void *pv) {
  VPBTrunk *trunk = (VPBTrunk*)pv;
  
  trunk->DialSync();
}

// This functions waits for sync (blocking) dial function to finish, then
// posts a finish event.  We need this in a separate thread to prevent 
// sync dial function from blocking other vpb events. 

void VPBTrunk::DialSync() {
  TrunkEvent event;

  slog(SLOG_INFO) <<__FILE__<<" line "<<__LINE__<< 
	  " digits= "<<data.dialxfer.digits << endl;

  slog(SLOG_INFO) <<__FILE__<<" line "<<__LINE__<< " dialing ..."<<endl;

  vpb_dial_sync(handle, data.dialxfer.digits);

  slog(SLOG_INFO) <<__FILE__<<" line "<<__LINE__<< " dialed ..."<<endl;

  event.id =  TRUNK_LINE_WINK;

  postEvent(&event);
}
